@@ -85,18 +85,22 @@ class DefectSystem(object):
         )
 
     @classmethod
-    def from_yaml(cls, filename: str) -> "DefectSystem":
+    def from_yaml(cls, filename: str, structure_file="", dos_file="") -> "DefectSystem":
         """generate ``DefectSystem`` via a yaml file.
 
         Args:
             filename (str): path to yaml file containing the ``DefectSystem``
               data
+            structure_file (str): path to file containing volume information.
+              Defaults to an empty string.
+            dos_file (str): path to file containing dos information. Defaults
+              to an empty string.
 
         Returns:
             DefectSystem: ``DefectSystem`` corresponding to provided yaml file
         """
 
-        input_set = InputSet.from_yaml(filename)
+        input_set = InputSet.from_yaml(filename, structure_file, dos_file)
         return cls(
             defect_species=input_set.defect_species,
             dos=input_set.dos,
